# device - manage igor devices

This plugin is primarily a set of user interfaces to allow you to inspect, add
and delete devices and sensors. You should probably be logged in as *admin*.

The device listing has links to the corresponding per-device data and plugin data,
and to any user interface the device plugin provides.

When you install a new device this plgugin will install the corresponding plugins, 
create capabilities and secret shared keys and actions.
